@@ -3,10 +3,10 @@ memory usage.
 
 """
 
-from ..common.system_info import memory_used
+from ..common.system_info import physical_memory_used
 
 from .decorators import data_source_generator
 
 @data_source_generator(name='Memory Usage')
 def memory_usage_data_source():
-    yield ('Memory/Physical', memory_used())
+    yield ('Memory/Physical', physical_memory_used())
